@@ -12,6 +12,9 @@ def rook_test():
         LoggingConfiguration.LOG_LEVEL = "DEBUG"
         LoggingConfiguration.LOG_TO_STDERR = True
 
+    from rook.config import AgentComConfiguration
+    AgentComConfiguration.TIMEOUT = 10
+
     try:
         import rook
 
