@@ -5,7 +5,7 @@ Since most serialization format do not support polymorphism, we add this capabil
 This module finds and loads all dynamic classes and dynamically builds the relevant component based on it's id.
 """
 
-import os
+import re
 
 import six
 
@@ -16,7 +16,7 @@ from ..augs.aug import Aug
 
 from .processor_extensions.operations.celery_rdb import CeleryRdb, CeleryRdbGetPort
 
-from rook.logger import logger
+
 from rook.rookout_json import json
 from rook import config
 
@@ -71,18 +71,28 @@ class AugFactory(Factory):
             six.raise_from(RookAugInvalidKey('action', json.dumps(configuration)), exc)
         action = self._get_dynamic_class(actionDict)
 
-        rate_limit = config.InstrumentationConfig.MIN_TIME_BETWEEN_HITS_MS
-        env_rate_limit = os.environ.get('ROOK_RULE_RATE_LIMIT', None)
-        if env_rate_limit:
-            try:
-                rate_limit = int(env_rate_limit)
-            except ValueError:
-                logger.warning("failed to convert rate limit from env-var: " + str(env_rate_limit))
+        limits_spec = configuration.get('rateLimit', None)
+        rate_limits = None
+
+        if limits_spec:
+            r = re.match(r'^(\d+)/(\d+)$', limits_spec)
+
+            if r is not None:
+                rate_limits = (int(r.group(1)), int(r.group(2)))
+
+        if not rate_limits:
+            rate_limits = (200, 5000)
 
-        min_time_between_hits = AugFactory.get_dict_value(configuration, 'minTimeBetweenHits', rate_limit)
         max_aug_execution_time = AugFactory.get_dict_value(configuration, 'maxAugTime', config.InstrumentationConfig.MAX_AUG_TIME)
 
-        return Aug(aug_id, location, extractor, condition, action, self._output, min_time_between_hits, max_aug_execution_time)
+        return Aug(aug_id=aug_id,
+                   location=location,
+                   extractor=extractor,
+                   condition=condition,
+                   action=action,
+                   output=self._output,
+                   max_aug_execution_time=max_aug_execution_time,
+                   rate_limits=rate_limits)
 
     def _load_dynamic_classes(self):
         """Load all dynamic classes into the factory."""
