@@ -1,14 +1,11 @@
-import os
 import datetime
 import traceback
+import decimal
 from types import FunctionType, MethodType, TracebackType
 from collections import Iterable
 
 import six
 
-if six.PY2:
-    from types import TypeType
-
 from google.protobuf.internal.type_checkers import Int32ValueChecker, Int64ValueChecker
 
 from .namespaces.container_namespace import ContainerNamespace
@@ -27,24 +24,20 @@ from .namespaces.delayed_namespace import DelayedNamespace
 
 from ..logger import logger
 
-try:
-    from rook.protobuf import rook_pb2
-except ImportError:
-    from rook.protobuf2 import variant_pb2 as rook_pb2
+from rook.protobuf import variant_pb2
 
-from rook.config import ProtobufConfiguration, ErrorConfiguration
+from rook.config import ProtobufConfiguration
 
 try:
     import numpy
 except ImportError:
     numpy = None
 
+if six.PY2:
+    from types import TypeType
+
 
 class NamespaceSerializer(object):
-
-    def __init__(self):
-        pass
-
     def dump(self, namespace, variant, log_errors=True):
         try:
             if isinstance(namespace, ContainerNamespace):
@@ -89,7 +82,7 @@ class NamespaceSerializer(object):
                 logger.exception(message)
 
     def dumps(self, namespace, log_errors=True):
-        variant = rook_pb2.Variant()
+        variant = variant_pb2.Variant()
         self.dump(namespace, variant, log_errors)
         return variant
 
@@ -235,12 +228,12 @@ class NamespaceSerializer(object):
     try:
         BINARY_TYPES = (buffer, bytearray)
         CODE_TYPES = (FunctionType, MethodType, TypeType)
-        PRIMITIVE_TYPES = (type(None), int, long, float, str, unicode, complex) + BINARY_TYPES + CODE_TYPES + (datetime.datetime,)
+        PRIMITIVE_TYPES = (type(None), int, long, float, str, unicode, complex, decimal.Decimal) + BINARY_TYPES + CODE_TYPES + (datetime.datetime,)
 
     except NameError:
         BINARY_TYPES = (bytearray, bytes)
         CODE_TYPES = (FunctionType, MethodType, type)
-        PRIMITIVE_TYPES = (type(None), int, float, str, complex) + BINARY_TYPES + CODE_TYPES + (datetime.datetime,)
+        PRIMITIVE_TYPES = (type(None), int, float, str, complex, decimal.Decimal) + BINARY_TYPES + CODE_TYPES + (datetime.datetime,)
 
     @staticmethod
     def _is_primitive(obj):
@@ -273,6 +266,13 @@ class NamespaceSerializer(object):
             variant.variant_type = variant.VARIANT_DOUBLE
             variant.double_value = float(obj)
 
+        elif isinstance(obj, decimal.Decimal):
+            serialized_decimal = str(obj)
+
+            variant.variant_type = variant.VARIANT_STRING
+            variant.string_value.original_size = len(serialized_decimal)
+            variant.string_value.value = serialized_decimal
+
         elif isinstance(obj, six.string_types):
             variant.variant_type = variant.VARIANT_STRING
             variant.string_value.original_size = len(obj)
@@ -324,6 +324,8 @@ class NamespaceSerializer(object):
         variant.list_value.type = ListNamespace.get_common_type(collection)
         if ListNamespace.is_numpy_obj(collection):
             collection = collection.tolist()
+            if not collection:
+                collection = []
         variant.list_value.original_size = len(collection)
 
         # Dump only if we are not too deep
@@ -365,6 +367,7 @@ class NamespaceSerializer(object):
         variant.variant_type = variant.VARIANT_OBJECT
 
     def _dump_not_supported(self, obj, variant):
+        logger.warning("Unsupported type in serializer: %s".format(type(obj)))
         variant.variant_type = variant.VARIANT_UKNOWN_OBJECT
 
     def _dump_dumped_object_namespace(self, namespace, variant, log_errors):
@@ -437,50 +440,54 @@ class NamespaceSerializer(object):
         # NOTE: This the common types are partially duplicated with PythonObjectNamespace.get_common_type
 
         try:
-            if variant.variant_type == rook_pb2.Variant.VARIANT_NONE:
+            if variant.variant_type == variant_pb2.Variant.VARIANT_NONE:
                 return DumpedPrimitiveNamespace(None, variant.original_type, "null", self._load_attributes(variant))
-            elif variant.variant_type == rook_pb2.Variant.VARIANT_INT:
+            elif variant.variant_type == variant_pb2.Variant.VARIANT_INT:
                 return DumpedPrimitiveNamespace(variant.int_value, variant.original_type, "int", self._load_attributes(variant))
-            elif variant.variant_type == rook_pb2.Variant.VARIANT_LONG:
+            elif variant.variant_type == variant_pb2.Variant.VARIANT_LONG:
                 return DumpedPrimitiveNamespace(variant.long_value, variant.original_type, "int", self._load_attributes(variant))
-            elif variant.variant_type == rook_pb2.Variant.VARIANT_DOUBLE:
+            elif variant.variant_type == variant_pb2.Variant.VARIANT_DOUBLE:
                 return DumpedPrimitiveNamespace(variant.double_value, variant.original_type, "float", self._load_attributes(variant))
-            elif variant.variant_type == rook_pb2.Variant.VARIANT_BINARY:
+            elif variant.variant_type == variant_pb2.Variant.VARIANT_BINARY:
                 return StringNamespace(variant.binary_value.value, variant.binary_value.original_size,
                                        variant.original_type, "binary", self._load_attributes(variant))
-            elif variant.variant_type == rook_pb2.Variant.VARIANT_STRING:
+            elif variant.variant_type == variant_pb2.Variant.VARIANT_STRING:
+                if variant.original_type == str(decimal.Decimal):
+                    return DumpedPrimitiveNamespace(
+                        decimal.Decimal(variant.string_value.value),
+                        variant.original_type, "float", self._load_attributes(variant))
                 return StringNamespace(variant.string_value.value, variant.string_value.original_size,
                                        variant.original_type, "string", self._load_attributes(variant))
-            elif variant.variant_type == rook_pb2.Variant.VARIANT_TIME:
+            elif variant.variant_type == variant_pb2.Variant.VARIANT_TIME:
                 return DumpedPrimitiveNamespace(variant.time_value.ToDatetime(), variant.original_type,
                                                 "datetime", self._load_attributes(variant))
-            elif variant.variant_type == rook_pb2.Variant.VARIANT_LIST:
+            elif variant.variant_type == variant_pb2.Variant.VARIANT_LIST:
                 return self._load_list(variant)
-            elif variant.variant_type == rook_pb2.Variant.VARIANT_MAP:
+            elif variant.variant_type == variant_pb2.Variant.VARIANT_MAP:
                 return self._load_dictionary(variant)
-            elif variant.variant_type == rook_pb2.Variant.VARIANT_OBJECT:
+            elif variant.variant_type == variant_pb2.Variant.VARIANT_OBJECT:
                 return self._load_user_class(variant)
-            elif variant.variant_type == rook_pb2.Variant.VARIANT_NAMESPACE:
+            elif variant.variant_type == variant_pb2.Variant.VARIANT_NAMESPACE:
                 return self._load_container_namespace(variant)
-            elif variant.variant_type == rook_pb2.Variant.VARIANT_ERROR:
+            elif variant.variant_type == variant_pb2.Variant.VARIANT_ERROR:
                 return self._load_error(variant.error_value)
-            elif variant.variant_type == rook_pb2.Variant.VARIANT_MAX_DEPTH:
+            elif variant.variant_type == variant_pb2.Variant.VARIANT_MAX_DEPTH:
                 return self._load_max_depth()
-            elif variant.variant_type == rook_pb2.Variant.VARIANT_FORMATTED_MESSAGE:
+            elif variant.variant_type == variant_pb2.Variant.VARIANT_FORMATTED_MESSAGE:
                 return self._load_formatted_namespace(variant)
-            elif variant.variant_type == rook_pb2.Variant.VARIANT_UKNOWN_OBJECT:
+            elif variant.variant_type == variant_pb2.Variant.VARIANT_UKNOWN_OBJECT:
                 return UnknownNamespace(variant.original_type, self._load_attributes(variant))
-            elif variant.variant_type == rook_pb2.Variant.VARIANT_CODE_OBJECT:
+            elif variant.variant_type == variant_pb2.Variant.VARIANT_CODE_OBJECT:
                 return self._load_code_object(variant)
-            elif variant.variant_type == rook_pb2.Variant.VARIANT_LARGE_INT:
+            elif variant.variant_type == variant_pb2.Variant.VARIANT_LARGE_INT:
                 return DumpedPrimitiveNamespace(int(variant.large_int_value.value), variant.original_type,
                                                 "int", self._load_attributes(variant))
-            elif variant.variant_type == rook_pb2.Variant.VARIANT_COMPLEX:
+            elif variant.variant_type == variant_pb2.Variant.VARIANT_COMPLEX:
                 return DumpedPrimitiveNamespace(complex(variant.complex_value.real, variant.complex_value.imaginary),
                                                 variant.original_type, "complex", self._load_attributes(variant))
-            elif variant.variant_type == rook_pb2.Variant.VARIANT_UNDEFINED:
+            elif variant.variant_type == variant_pb2.Variant.VARIANT_UNDEFINED:
                 return DumpedPrimitiveNamespace(None, variant.original_type, "null", self._load_attributes(variant))
-            elif variant.variant_type == rook_pb2.Variant.VARIANT_DYNAMIC:
+            elif variant.variant_type == variant_pb2.Variant.VARIANT_DYNAMIC:
                 return DynamicObjectNamespace()
             else:
                 raise ValueError("Invalid type", variant.variant_type)
