@@ -26,17 +26,3 @@ class DumpedObjectNamespace(Namespace):
 
     def serialize_type(self):
         return type
-
-    def get_attributes_dict(self):
-        attributes = {}
-        for key, value in six.iteritems(self.attributes):
-            attributes[key] = value.to_dict()
-
-        return attributes
-
-    def get_attributes_simple_dict(self):
-        attributes = {}
-        for key, value in six.iteritems(self.attributes):
-            attributes[key] = value.to_simple_dict()
-
-        return attributes
