@@ -31,9 +31,3 @@ class Namespace(object):
             return self[key]
         except KeyError:
             raise RookAttributeNotFound(key)
-
-    def to_dict(self):
-        raise NotImplementedError()
-
-    def to_simple_dict(self):
-        raise NotImplementedError()
