@@ -15,25 +15,20 @@ class PythonObjectNamespace(Namespace):
 
     class ObjectDumpConfig(object):
 
-        STRICT_MAX_DEPTH = 1
-        STRICT_MAX_WIDTH = 3
+        STRICT_MAX_DEPTH = 2
+        STRICT_MAX_WIDTH = 10
         STRICT_MAX_COLLECTION_DEPTH = 1
-        STRICT_MAX_STRING = 16
+        STRICT_MAX_STRING = 128
 
         DEFAULT_MAX_DEPTH = 3
         DEFAULT_MAX_WIDTH = 20
         DEFAULT_MAX_COLLECTION_DEPTH = 2
         DEFAULT_MAX_STRING = 512
 
-        TOLERANT_MAX_DEPTH = 10
-        TOLERANT_MAX_WIDTH = 100
-        TOLERANT_MAX_COLLECTION_DEPTH = 10
-        TOLERANT_MAX_STRING = 64 * 1024
-
-        CONSERVATIVE_MAX_DEPTH = 5
-        CONSERVATIVE_MAX_WIDTH = 20
-        CONSERVATIVE_MAX_COLLECTION_DEPTH = 2
-        CONSERVATIVE_MAX_STRING = 256
+        TOLERANT_MAX_DEPTH = 5
+        TOLERANT_MAX_WIDTH = 50
+        TOLERANT_MAX_COLLECTION_DEPTH = 4
+        TOLERANT_MAX_STRING = 4 * 1024
 
         UNLIMITED_STRING = 64 * 1024
         UNLIMITED_COLLECTION_WIDTH = 100
@@ -75,14 +70,6 @@ class PythonObjectNamespace(Namespace):
                 cls.TOLERANT_MAX_COLLECTION_DEPTH,
                 cls.TOLERANT_MAX_STRING)
 
-        @classmethod
-        def conservative_limits(cls, obj):
-            return cls(
-                cls.CONSERVATIVE_MAX_DEPTH,
-                cls.CONSERVATIVE_MAX_WIDTH,
-                cls.CONSERVATIVE_MAX_COLLECTION_DEPTH,
-                cls.CONSERVATIVE_MAX_STRING)
-
         @classmethod
         def tailor_limits(cls, obj):
             if isinstance(obj, six.string_types):
@@ -131,7 +118,7 @@ class PythonObjectNamespace(Namespace):
     def read_key(self, key):
         try:
             return PythonObjectNamespace(self.obj[key])
-        except (KeyError, IndexError):
+        except (KeyError, IndexError, TypeError):
             raise RookKeyNotFound(key)
 
     def type(self, args=None):
@@ -183,29 +170,6 @@ class PythonObjectNamespace(Namespace):
 
         return self
 
-    def to_dict(self):
-        result = {
-            u'@namespace': self.__class__.__name__,
-            u'@common_type': self.get_common_type(self.obj),
-            u'@original_type': self.serialize_type(),
-            }
-
-        if hasattr(self.obj,'__dict__'):
-            result['@attributes'] = self.obj.__dict__
-        else:
-            result['@attributes'] = {}
-
-        if six.PY2 and isinstance(self.obj, str):
-            result[u'@value'] = unicode(self.obj, errors='replace')
-        elif six.PY2 and isinstance(self.obj, (int, long, float, str, unicode, buffer, bytearray, bytes, list, dict, set, frozenset)) or \
-            six.PY3 and isinstance(self.obj, (int, float, str, bytes, bytearray, list, dict, set, frozenset)):
-            result[u'@value'] = self.obj
-
-        return result
-
-    def to_simple_dict(self):
-        return self.obj
-
     def __hash__(self):
         return hash(self.obj)
 
