@@ -21,10 +21,10 @@ ops = {"NE": "!=",
        "GT": ">",
        "GE": ">=",
        "LE": "<=",
-       "AND": " and ",
-       "OR": " or ",
-       "&&": " and ",
-       "||": " or "}
+       "AND": "and",
+       "OR": "or",
+       "&&": "and",
+       "||": "or"}
 
 
 level1 = ["*", "/"]
@@ -116,6 +116,9 @@ class NamespaceResult(Marker):
     def to_string(self):
         return self.text
 
+    def get_obj(self):
+        return self.obj.obj
+
 
 class NonPrimitiveNamespaceResult(NamespaceResult):
     def __init__(self, namespace, path):
@@ -128,12 +131,15 @@ class NonPrimitiveNamespaceResult(NamespaceResult):
 
 class Text(Marker):
     def __init__(self, string):
-        self.obj = "'" + string + "'"
+        self.obj = string
         self.text = string
 
     def to_string(self):
         return self.obj
 
+    def get_obj(self):
+        return self.obj
+
 
 class TextResult(Marker):
     def __init__(self, string):
@@ -143,6 +149,9 @@ class TextResult(Marker):
     def to_string(self):
         return str(self.text)
 
+    def get_obj(self):
+        return self.obj
+
 
 class Array(Marker):
     def __init__(self, l, string):
@@ -152,6 +161,9 @@ class Array(Marker):
     def to_string(self):
         return self.text
 
+    def get_obj(self):
+        return self.obj
+
 
 class FloatNumber(Marker):
     def __init__(self, num):
@@ -161,6 +173,9 @@ class FloatNumber(Marker):
     def to_string(self):
         return self.text
 
+    def get_obj(self):
+        return self.obj
+
 
 class Number(Marker):
     def __init__(self, num):
@@ -170,6 +185,9 @@ class Number(Marker):
     def to_string(self):
         return str(self.obj)
 
+    def get_obj(self):
+        return self.obj
+
 
 class Char(Marker):
     def __init__(self, char):
@@ -179,6 +197,9 @@ class Char(Marker):
     def to_string(self):
         return self.obj
 
+    def get_obj(self):
+        return self.obj
+
 
 class Bool(Marker):
     def __init__(self, boolean):
@@ -188,6 +209,9 @@ class Bool(Marker):
     def to_string(self):
         return str(self.obj)
 
+    def get_obj(self):
+        return self.obj
+
 
 class Undefined(Marker):
     def __init__(self):
@@ -198,8 +222,29 @@ class Undefined(Marker):
     def to_string():
         return 'None'
 
+    def get_obj(self):
+        return self.obj
+
 
 class Opt(Marker):
+    _opMap = {
+        "+": lambda a, b: a + b,
+        "-": lambda a, b: a - b,
+        "/": lambda a, b: a / b,
+        "*": lambda a, b: a * b,
+
+        "<": lambda a, b: a < b,
+        "<=": lambda a, b: a <= b,
+        ">": lambda a, b: a > b,
+        ">=": lambda a, b: a >= b,
+        "!=": lambda a, b: a != b,
+        "=": lambda a, b: a == b,
+        "==": lambda a, b: a == b,
+        #"in": lambda a, b: a in b,  # should use this...
+        "and": lambda a, b: a and b,
+        "or": lambda a, b: a or b,
+    }
+
     def __init__(self, opt):
         self.opt = opt
         self.level = None
@@ -228,22 +273,49 @@ class Opt(Marker):
             #TODO:: throw exception
             pass
 
+    @staticmethod
+    def get_element_string(element):
+        if isinstance(element, NamespaceResult):
+            return element.to_string().strip('\'')
+        else:
+            return element.text
+
     def execute_operation(self, a, b):
         if self.level == 3:
-            if not isinstance(b, Array):
+            first_element_string = Opt.get_element_string(a)
+
+            if not first_element_string:
                 return Bool('False')
 
-            for e in b.obj:
-                if e.text == a.text and e.obj == a.obj:
-                    return Bool('True')
+            if not isinstance(b, Array) and not isinstance(b, NamespaceResult) and not isinstance(b, Text):
+                return Bool('False')
+
+            if isinstance(b, NamespaceResult):
+                if isinstance(b.obj.obj, list):
+                    for e in b.obj.obj:
+                        if str(e) == first_element_string:
+                            return Bool('True')
+                elif isinstance(b.obj.obj, six.string_types):
+                    if first_element_string in b.obj.obj:
+                        return Bool('True')
+
+            elif isinstance(b, Array):
+                for e in b.obj:
+                    if e.text == first_element_string and e.obj == a.obj:
+                        return Bool('True')
+
+            else:
+                if isinstance(a.obj, six.string_types):
+                    if first_element_string in b.obj:
+                        return Bool('True')
 
             return Bool('False')
         else:
-            operation = a.to_string() + self.opt + b.to_string()
             try:
-                result = eval(operation)
-            except TypeError as e:
-                raise RookExceptionEvaluationFailed(str(e))
+                result = Opt._opMap[self.opt](a.get_obj(), b.get_obj())
+            except Exception as e:
+                operation = a.to_string() + self.opt + b.to_string()
+                raise RookExceptionEvaluationFailed(str(e) + " : " + operation)
 
             if isinstance(result, bool):
                 if not result:
