@@ -6,18 +6,26 @@ import os
 import sys
 import platform
 import atexit
+import uuid
 
 # This must be the first import, otherwise enable_gevent_for_grpc will fail since grpc has already been imported
 from rook.logger import logger
 
-from rook.config import ControllerAddress, AgentComConfiguration
+from rook.config import AgentComConfiguration
+
+from rook.com_ws.output_ws import Output
 
 from .augs.augs_manager import AugsManager
 from .trigger_services import TriggerServices
 
 from rook.exceptions import RookInterfaceException, RookVersionNotSupported
+from rook.com_ws.agent_com_ws import AgentCom
+from rook.com_ws.command_handler import CommandHandler
 
-from .atfork import install_fork_handler
+try:
+    from .atfork import install_fork_handler, remove_fork_handler
+except ImportError:
+    pass
 
 
 class _Singleton(object):
@@ -31,12 +39,13 @@ class _Singleton(object):
 
         logger.info("Initializing Rook under process-%d", os.getpid())
 
+        self._id = None
         self._services_started = False
 
         self._trigger_services = TriggerServices()
+        self._command_handler = None
         self._aug_manager = None
         self._fork_handler = None
-        self._output = None
 
         self._agent_com = None
 
@@ -49,9 +58,8 @@ class _Singleton(object):
         if self._services_started:
             return
 
-        if self._output is None:
-            from rook.com.output import Output
-            self._output = Output(self._trigger_services)
+        self._id = uuid.uuid4().hex
+        self._output = Output(self._id)
 
         self._trigger_services.start()
         self._aug_manager = AugsManager(self._trigger_services, self._output)
@@ -69,64 +77,26 @@ class _Singleton(object):
     def get_trigger_services(self):
         return self._trigger_services
 
-    def connect(self, token, host, port, tags=None, labels=None, async_start=False):
+    def connect(self, token, host, port, proxy, tags=None, labels=None, async_start=False):
         """Connect to the Agent."""
         if self._agent_com:
             raise RookInterfaceException("Multiple connection attempts not supported!")
 
-        self._fork_handler = install_fork_handler()
-
-        if not host:
-            host = ControllerAddress.HOST
-
-        if not port:
-            port = int(ControllerAddress.PORT)
-
-        if not token:
-            token = os.environ.get('ROOKOUT_TOKEN')
+        if install_fork_handler:
+            install_fork_handler()
 
         logger.debug("Initiating AgentCom-\t%s:%d", host, int(port))
-        if host.startswith('ws://') or host.startswith('wss://'):
-            from rook.protobuf2 import variant_pb2
-            import rook.processor.namespace_serializer
-            rook.processor.namespace_serializer.rook_pb2 = variant_pb2
 
-            from rook.com_ws.agent_com_ws import AgentCom
-            from rook.com_ws.command_handler import CommandHandler
-            from rook.com_ws.output_ws import Output
+        labels = labels or {}
+        tags = tags or []
 
-            labels = labels or {}
-            tags = tags or []
-
-            self._output = Output()
-            self._agent_com = AgentCom(host, port, token, labels, tags)
-            self._start_trigger_services()
-            self._command_handler = CommandHandler(self._agent_com, self._aug_manager)
-            self._output.set_agent_com(self._agent_com)
-            self._agent_com.start()
-            if async_start is False:
-                self._agent_com.wait_for_ready(AgentComConfiguration.GRPC_TIMEOUT)
-        else:
-            from .com.agent_com import AgentCom
-            from rook.com.output import Output
-
-            if async_start is True:
-                AgentComConfiguration.GRPC_TIMEOUT = 0
-
-            self._output = Output(self._trigger_services)
-
-            if tags is not None:
-                self._output.tags = tags
-            if labels is not None:
-                self._output.labels = labels
-
-            self._start_trigger_services()
-            self._agent_com = AgentCom(self._aug_manager, self._trigger_services, self._output, host, port, token)
-            self._output.set_agent_com(self._agent_com)
-            self._agent_com.start()
-
-
-    logger.info("Successful connection to agent")
+        self._start_trigger_services()
+        self._agent_com = AgentCom(self._id, host, port, proxy, token, labels, tags)
+        self._command_handler = CommandHandler(self._agent_com, self._aug_manager)
+        self._output.set_agent_com(self._agent_com)
+        self._agent_com.start()
+        if async_start is False:
+            self._agent_com.wait_for_ready(AgentComConfiguration.TIMEOUT)
 
     def flush(self):
         self._output.flush_messages()
@@ -136,16 +106,35 @@ class _Singleton(object):
 
         if self._agent_com is not None:
             self._agent_com.stop()
+        self._agent_com = None
 
         self._stop_trigger_services()
 
-        self._agent_com = None
+    def pre_fork(self):
+        # AgentCom is fork safe (the child will lose the thread) so there's nothing we need to do with it
+        self._trigger_services.pre_fork()
+
+    def post_fork_recover(self):
+        self._trigger_services.post_fork()
+
+    def post_fork_clean(self):
+        self._trigger_services.post_fork()
+
+        self._command_handler = None
+
+        if self._agent_com:
+            self._agent_com.stop()
+            self._agent_com = None
+
+        self._stop_trigger_services()
+        if remove_fork_handler:
+            remove_fork_handler()
 
     @staticmethod
     def _check_version_supported():
         try:
             supported_platforms = ['pypy', 'cpython']
-            supported_version = ['2.7', '3.5', '3.6', '3.7']
+            supported_version = ['2.7', '3.5', '3.6', '3.7', '3.8']
 
             current_platform = platform.python_implementation().lower()
             if current_platform not in supported_platforms:
@@ -168,11 +157,12 @@ singleton_obj = _Singleton()
 
 def exit_handler():
     try:
-        logger.info("Exit handler called - flushing")
+        logger.info("Exit handler called - flushing and closing WebSocket")
         if singleton_obj._agent_com:
             singleton_obj.flush()
+            singleton_obj._agent_com.stop()
     except:
-        logger.exception("Flush failed")
+        logger.exception("Flush and close failed")
     logger.info("Exit handler finished")
 
 
